@@ -23,7 +23,7 @@ def check_resp_items(item):
             return item
         else:
             for key, value in item.items():
-                if isinstance(item[key], str):
+                if isinstance(item[key], (str, unicode)):
                     if item[key].__len__() > 1000:
                         item[key] = None
                 elif isinstance(item[key], dict):
@@ -34,11 +34,6 @@ def check_resp_items(item):
                     continue
     except Exception as err:
         print('日志参数处理异常 err=%s' % err)
-        if isinstance(item, str):
-            if len(item) > 3000:
-                return item[:3000]
-            else:
-                return item
     return item
 
 
